@@ -1,5 +1,5 @@
 var __WINDOW_SIZE = [window.width, window.height];
 
-$(window).resize(function () {
+$(document).ready(function () {
     window.resizeTo(1200, 900);
 });
\ No newline at end of file
